@@ -30,16 +30,16 @@
     </message>
     <message>
         <location filename="../selectwnd.ui" line="65"/>
-        <source>Size</source>
-        <translation>Tamaina</translation>
+        <source>Size:</source>
+        <translation>Tamaina:</translation>
     </message>
     <message>
-        <location filename="../selectwnd.cpp" line="229"/>
+        <location filename="../selectwnd.cpp" line="231"/>
         <source>XCurTheme error</source>
         <translation>XCurTheme errorea</translation>
     </message>
     <message>
-        <location filename="../selectwnd.cpp" line="230"/>
+        <location filename="../selectwnd.cpp" line="232"/>
         <source>You can&apos;t remove active theme!</source>
         <translation>Ezin duzu gai aktiboa kendu!</translation>
     </message>
