@@ -99,6 +99,11 @@
         <source>Font hinting style:</source>
         <translation>Қаріпті хинтингтеу стилі:</translation>
     </message>
+    <message>
+        <location filename="../fontsconfig.ui" line="211"/>
+        <source>Monospace:</source>
+        <translation>Тең енді:</translation>
+    </message>
     <message>
         <location filename="../fontsconfig.ui" line="118"/>
         <location filename="../fontsconfig.ui" line="164"/>
@@ -164,27 +169,27 @@
 <context>
     <name>GTKConfig</name>
     <message>
-        <location filename="../gtkconfig.ui" line="44"/>
+        <location filename="../gtkconfig.ui" line="56"/>
         <source>GTK Style</source>
         <translation>GTK стилі</translation>
     </message>
     <message>
-        <location filename="../gtkconfig.ui" line="63"/>
+        <location filename="../gtkconfig.ui" line="75"/>
         <source>Set GTK themes (GTK configuration files will be overwritten!)</source>
         <translation>GTK рәсімдеу тәсілдерін орнату (GTK конфигурациялық файлы қайта жазылады)</translation>
     </message>
     <message>
-        <location filename="../gtkconfig.ui" line="93"/>
+        <location filename="../gtkconfig.ui" line="105"/>
         <source>GTK 3 Theme:</source>
         <translation>GTK 3 рәсімдеу тәсілі:</translation>
     </message>
     <message>
-        <location filename="../gtkconfig.ui" line="77"/>
+        <location filename="../gtkconfig.ui" line="89"/>
         <source>GTK 2 Theme:</source>
         <translation>GTK 2 рәсімдеу тәсілі:</translation>
     </message>
     <message>
-        <location filename="../gtkconfig.ui" line="105"/>
+        <location filename="../gtkconfig.ui" line="117"/>
         <source>To attempt uniform theming, either select similar style/theme (if available) across all lists, or select &apos;gtk2&apos; Qt style (if available) to mimic GTK themes.
 
 Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply themes on the fly.</source>
@@ -226,22 +231,22 @@ GTK бағдарламалары рәсімдеу стильдерін бірд
     <message>
         <location filename="../lxqtthemeconfig.ui" line="57"/>
         <source>Use wallpaper provided by theme</source>
-        <translation type="unfinished"></translation>
+        <translation>Тема ұсынған тұсқағазды қолдану</translation>
     </message>
     <message>
         <location filename="../lxqtthemeconfig.ui" line="64"/>
         <source>Use palette provided by theme</source>
-        <translation type="unfinished"></translation>
+        <translation>Тема ұсынған палитраны қолдану</translation>
     </message>
     <message>
         <location filename="../lxqtthemeconfig.cpp" line="83"/>
         <source>(User Theme)</source>
-        <translation type="unfinished"></translation>
+        <translation>(Пайдаланушы темасы)</translation>
     </message>
     <message>
         <location filename="../lxqtthemeconfig.cpp" line="188"/>
         <source>Open theme folder</source>
-        <translation type="unfinished"></translation>
+        <translation>Тема бумасын ашу</translation>
     </message>
 </context>
 <context>
@@ -250,17 +255,17 @@ GTK бағдарламалары рәсімдеу стильдерін бірд
         <location filename="../palettes.ui" line="14"/>
         <location filename="../palettes.ui" line="20"/>
         <source>Palettes</source>
-        <translation type="unfinished"></translation>
+        <translation>Палитралар</translation>
     </message>
     <message>
         <location filename="../palettes.ui" line="33"/>
         <source>Filter...</source>
-        <translation type="unfinished"></translation>
+        <translation>Сүзгі...</translation>
     </message>
     <message>
         <location filename="../palettes.ui" line="43"/>
         <source>&amp;Remove</source>
-        <translation type="unfinished"></translation>
+        <translation>Өші&amp;ру</translation>
     </message>
 </context>
 <context>
@@ -268,227 +273,229 @@ GTK бағдарламалары рәсімдеу стильдерін бірд
     <message>
         <location filename="../main.cpp" line="61"/>
         <source>LXQt Appearance Configuration</source>
-        <translation type="unfinished">LXQt келбетін реттеу</translation>
+        <translation>LXQt сыртқы түрін баптау</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="74"/>
         <source>Widget Style</source>
-        <translation type="unfinished"></translation>
+        <translation>Виджет стилі</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="83"/>
         <source>Icons Theme</source>
-        <translation type="unfinished">Белгішелер рәсімдеу тәсілі</translation>
+        <translation>Таңбашалар темасы</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="92"/>
         <source>LXQt Theme</source>
-        <translation type="unfinished">LXQt рәсімдеу тәсілі</translation>
+        <translation>LXQt темасы</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="100"/>
         <source>Font</source>
-        <translation type="unfinished">Қаріп</translation>
+        <translation>Қаріп</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="110"/>
         <source>Cursor</source>
-        <translation type="unfinished"></translation>
+        <translation>Курсор</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="117"/>
         <source>GTK Style</source>
-        <translation type="unfinished">GTK стилі</translation>
+        <translation>GTK стилі</translation>
     </message>
 </context>
 <context>
     <name>StyleConfig</name>
     <message>
-        <location filename="../styleconfig.ui" line="33"/>
+        <location filename="../styleconfig.ui" line="45"/>
         <source>Widget Style</source>
-        <translation type="unfinished"></translation>
+        <translation>Виджет стилі</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="75"/>
+        <source>Qt Palette</source>
+        <translation>Qt палитрасы</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="89"/>
+        <source>Some Qt styles may ignore these colors.</source>
+        <translation>Кейбір Qt стильдері бұл түстерді елемеуі мүмкін.</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="114"/>
+        <source>Window:</source>
+        <translation>Терезе:</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="124"/>
+        <source>View:</source>
+        <translation>Көрініс:</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="134"/>
+        <source>Selection:</source>
+        <translation>Таңдау:</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="144"/>
+        <source>Tooltip:</source>
+        <translation>Қалқымалы нұсқама:</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="158"/>
+        <source>Link:</source>
+        <translation>Сілтеме:</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="178"/>
+        <source>Window Text:</source>
+        <translation>Терезе мәтіні:</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="188"/>
+        <source>View Text:</source>
+        <translation>Көрініс мәтіні:</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="198"/>
+        <source>Selected Text:</source>
+        <translation>Таңдалған мәтін:</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="208"/>
+        <source>Tooltip Text:</source>
+        <translation>Қалқымалы нұсқама мәтіні:</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="222"/>
+        <source>Visited Link:</source>
+        <translation>Қаралған сілтеме:</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="254"/>
+        <source>&amp;Save Palette</source>
+        <translation>Палитраны &amp;сақтау</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="261"/>
+        <source>&amp;Load Palette</source>
+        <translation>&amp;Палитраны жүктеу</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="281"/>
+        <source>&amp;Default Palette</source>
+        <translation>Әдепкі &amp;палитра</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="296"/>
+        <location filename="../styleconfig.ui" line="306"/>
+        <location filename="../styleconfig.ui" line="338"/>
+        <location filename="../styleconfig.ui" line="348"/>
+        <location filename="../styleconfig.ui" line="380"/>
+        <source>May be overridden by Qt style or app</source>
+        <translation>Qt стилі немесе қолданба арқылы қайта анықталуы мүмкін</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="299"/>
+        <source>Toolbar button style:</source>
+        <translation>Саймандар панелі батырмаларының стилі:</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="310"/>
+        <source>Only display the icon</source>
+        <translation>Тек таңбашаны көрсету</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="315"/>
+        <source>Only display the text</source>
+        <translation>Тек мәтінді көрсету</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="320"/>
+        <source>The text appears beside the icon</source>
+        <translation>Мәтін таңбашаның қасында көрсетіледі</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="325"/>
+        <source>The text appears under the icon</source>
+        <translation>Мәтін таңбашаның астында көрсетіледі</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="330"/>
+        <source>Default</source>
+        <translation>Бастапқы</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="341"/>
+        <source>Toolbar icon size:</source>
+        <translation>Сайман тақтасы таңбашаларының өлшемі:</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="352"/>
+        <source>16</source>
+        <translation>16</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="357"/>
+        <source>22</source>
+        <translation>22</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="362"/>
+        <source>24</source>
+        <translation>24</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="367"/>
+        <source>32</source>
+        <translation>32</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="372"/>
+        <source>48</source>
+        <translation>48</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="383"/>
+        <source>Activate item on single click</source>
+        <translation>Элементті бір шертумен белсендіру</translation>
     </message>
     <message>
         <location filename="../styleconfig.ui" line="63"/>
-        <source>Qt Palette</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../styleconfig.ui" line="77"/>
-        <source>Some Qt styles may ignore these colors.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../styleconfig.ui" line="102"/>
-        <source>Window:</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../styleconfig.ui" line="112"/>
-        <source>View:</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../styleconfig.ui" line="122"/>
-        <source>Selection:</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../styleconfig.ui" line="132"/>
-        <source>Tooltip:</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../styleconfig.ui" line="146"/>
-        <source>Link:</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../styleconfig.ui" line="166"/>
-        <source>Window Text:</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../styleconfig.ui" line="176"/>
-        <source>View Text:</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../styleconfig.ui" line="186"/>
-        <source>Selected Text:</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../styleconfig.ui" line="196"/>
-        <source>Tooltip Text:</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../styleconfig.ui" line="210"/>
-        <source>Visited Link:</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../styleconfig.ui" line="242"/>
-        <source>&amp;Save Palette</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../styleconfig.ui" line="249"/>
-        <source>&amp;Load Palette</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../styleconfig.ui" line="269"/>
-        <source>&amp;Default Palette</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../styleconfig.ui" line="284"/>
-        <location filename="../styleconfig.ui" line="294"/>
-        <location filename="../styleconfig.ui" line="326"/>
-        <location filename="../styleconfig.ui" line="336"/>
-        <location filename="../styleconfig.ui" line="368"/>
-        <source>May be overridden by Qt style or app</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../styleconfig.ui" line="287"/>
-        <source>Toolbar button style:</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../styleconfig.ui" line="298"/>
-        <source>Only display the icon</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../styleconfig.ui" line="303"/>
-        <source>Only display the text</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../styleconfig.ui" line="308"/>
-        <source>The text appears beside the icon</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../styleconfig.ui" line="313"/>
-        <source>The text appears under the icon</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../styleconfig.ui" line="318"/>
-        <source>Default</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../styleconfig.ui" line="329"/>
-        <source>Toolbar icon size:</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../styleconfig.ui" line="340"/>
-        <source>16</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../styleconfig.ui" line="345"/>
-        <source>22</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../styleconfig.ui" line="350"/>
-        <source>24</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../styleconfig.ui" line="355"/>
-        <source>32</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../styleconfig.ui" line="360"/>
-        <source>48</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../styleconfig.ui" line="371"/>
-        <source>Activate item on single click</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../styleconfig.ui" line="51"/>
         <source>Qt Style:</source>
-        <translation type="unfinished"></translation>
+        <translation>Qt стилі:</translation>
     </message>
     <message>
         <location filename="../styleconfig.cpp" line="330"/>
         <location filename="../styleconfig.cpp" line="340"/>
         <source>Save Palette</source>
-        <translation type="unfinished"></translation>
+        <translation>Палитраны сақтау</translation>
     </message>
     <message>
         <location filename="../styleconfig.cpp" line="330"/>
         <source>Palette name:</source>
-        <translation type="unfinished"></translation>
+        <translation>Палитра атауы:</translation>
     </message>
     <message>
         <location filename="../styleconfig.cpp" line="341"/>
         <source>A palette with the same name exists.
 Do you want to replace it?</source>
-        <translation type="unfinished"></translation>
+        <translation>Осындай атаумен палитра бар.
+Оны ауыстыруды қалайсыз ба?</translation>
     </message>
     <message>
         <location filename="../styleconfig.cpp" line="484"/>
         <source>Remove Palettes</source>
-        <translation type="unfinished"></translation>
+        <translation>Палитраларды өшіру</translation>
     </message>
     <message>
         <location filename="../styleconfig.cpp" line="485"/>
         <source>Do you really want to remove selected palette(s)?
 Root palettes will remain intact if existing.</source>
-        <translation type="unfinished"></translation>
+        <translation>Таңдалған палитраны(ларды) өшіруді шынымен қалайсыз ба?
+Түбірлік палитралар бар болса, өзгеріссіз қалады.</translation>
     </message>
 </context>
 </TS>
