@@ -40,12 +40,17 @@
         <translation>დადასტურების მოთხოვნა პარამეტრის ცვლილების შემდეგ</translation>
     </message>
     <message>
-        <location filename="../brightnesssettings.cpp" line="115"/>
+        <location filename="../brightnesssettings.cpp" line="54"/>
+        <source>Currently unsupported under Wayland</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../brightnesssettings.cpp" line="122"/>
         <source>Brightness settings changed</source>
         <translation>სიკაშკაშის პარამეტრები შეიცვალა</translation>
     </message>
     <message>
-        <location filename="../brightnesssettings.cpp" line="116"/>
+        <location filename="../brightnesssettings.cpp" line="123"/>
         <source>Confirmation required. Are the settings correct?</source>
         <translation>დადასტურება აუცილებელია. ეს პარამეტრები სწორია?</translation>
     </message>
