@@ -20,10 +20,19 @@
 #include "touchpaddevice.h"
 
 #include <cmath>
+
+#include <QDebug>
+#include <QFile>
+#include <QString>
 #include <QUrl>
+
+#include <XdgDirs>
+
 #include <LXQt/AutostartEntry>
 #include <LXQt/Settings>
 
+using namespace Qt::Literals::StringLiterals;
+
 TouchpadConfig::TouchpadConfig(LXQt::Settings* _settings, QWidget* parent):
     QWidget(parent),
     settings(_settings)
@@ -38,16 +47,20 @@ TouchpadConfig::TouchpadConfig(LXQt::Settings* _settings, QWidget* parent):
 
     initControls();
 
-    connect(ui.devicesComboBox, QOverload<int>::of(&QComboBox::currentIndexChanged),
-            this, [this] (int/* index*/) { initControls(); }); // update GUI on device change
+    connect(ui.devicesComboBox, &QComboBox::currentIndexChanged, this,
+            [this] (int /*index*/) { initControls(); }); // update GUI on device change
     connect(ui.tappingEnabledCheckBox, &QAbstractButton::clicked, this, &TouchpadConfig::settingsChanged);
     connect(ui.naturalScrollingEnabledCheckBox, &QAbstractButton::clicked, this, &TouchpadConfig::settingsChanged);
+    connect(ui.disableWhileTypingCheckBox, &QAbstractButton::clicked, this, &TouchpadConfig::settingsChanged);
     connect(ui.tapToDragEnabledCheckBox, &QAbstractButton::clicked, this, &TouchpadConfig::settingsChanged);
-    connect(ui.accelSpeedDoubleSpinBox, QOverload<double>::of(&QDoubleSpinBox::valueChanged), this, &TouchpadConfig::settingsChanged);
+    connect(ui.dragLockEnabledCheckBox, &QAbstractButton::clicked, this, &TouchpadConfig::settingsChanged);
+    connect(ui.accelSpeedDoubleSpinBox, &QDoubleSpinBox::valueChanged, this, &TouchpadConfig::settingsChanged);
     connect(ui.noScrollingRadioButton, &QAbstractButton::clicked, this, &TouchpadConfig::settingsChanged);
     connect(ui.twoFingerScrollingRadioButton, &QAbstractButton::clicked, this, &TouchpadConfig::settingsChanged);
     connect(ui.edgeScrollingRadioButton, &QAbstractButton::clicked, this, &TouchpadConfig::settingsChanged);
     connect(ui.buttonScrollingRadioButton, &QAbstractButton::clicked, this, &TouchpadConfig::settingsChanged);
+
+    connect(ui.tapToDragEnabledCheckBox, &QCheckBox::toggled, ui.dragLockEnabledCheckBox, &QCheckBox::setEnabled);
 }
 
 TouchpadConfig::~TouchpadConfig()
@@ -77,7 +90,11 @@ void TouchpadConfig::initControls()
     const TouchpadDevice& device = devices[curDevice];
     initFeatureControl(ui.tappingEnabledCheckBox, device.tappingEnabled());
     initFeatureControl(ui.naturalScrollingEnabledCheckBox, device.naturalScrollingEnabled());
+    initFeatureControl(ui.disableWhileTypingCheckBox, device.disableWhileTypingEnabled());
     initFeatureControl(ui.tapToDragEnabledCheckBox, device.tapToDragEnabled());
+    initFeatureControl(ui.dragLockEnabledCheckBox, device.dragLockEnabled());
+
+    ui.dragLockEnabledCheckBox->setEnabled(ui.tapToDragEnabledCheckBox->isChecked());
 
     auto ok = device.xinputDriverSupported();
     if (!ok) {
@@ -136,10 +153,23 @@ void TouchpadConfig::accept()
         device.saveSettings(settings);
     }
 
-    LXQt::AutostartEntry autoStart(QStringLiteral("lxqt-config-touchpad-autostart.desktop"));
-    XdgDesktopFile desktopFile(XdgDesktopFile::ApplicationType, QStringLiteral("lxqt-config-touchpad-autostart"), QStringLiteral("lxqt-config-input --load-touchpad"));
-    desktopFile.setValue(QStringLiteral("OnlyShowIn"), QStringLiteral("LXQt"));
-    desktopFile.setValue(QStringLiteral("Comment"), QStringLiteral("Autostart touchpad settings for lxqt-config-input"));
+    LXQt::AutostartEntry autoStart;
+    XdgDesktopFile desktopFile;
+
+    const QStringList dirs = XdgDirs::dataDirs();
+    auto it = dirs.cbegin();
+    for ( ;it != dirs.cend(); ++it) {
+        const QString fn = *it + "/applications/lxqt-config-touchpad-autostart.desktop"_L1;
+        if (QFile::exists(fn))
+            if (desktopFile.load(fn)) {
+                autoStart.setFile(desktopFile);
+                autoStart.commit();
+                break;
+            }
+        }
+        if (it == dirs.cend()) {
+            qWarning() << " TouchpadConfig::accept(): LXQt Config Touchpad autostart file not found";
+        }
     autoStart.setFile(desktopFile);
     autoStart.commit();
 }
@@ -150,7 +180,9 @@ void TouchpadConfig::reset()
     {
         device.setTappingEnabled(device.oldTappingEnabled());
         device.setNaturalScrollingEnabled(device.oldNaturalScrollingEnabled());
+        device.setDisableWhileTypingEnabled(device.oldDisableWhileTypingEnabled());
         device.setTapToDragEnabled(device.oldTapToDragEnabled());
+        device.setDragLockEnabled(device.oldDragLockEnabled());
         device.setAccelSpeed(device.oldAccelSpeed());
         device.setScrollingMethodEnabled(device.oldScrollingMethodEnabled());
     }
@@ -182,6 +214,13 @@ void TouchpadConfig::applyConfig()
         acceptSetting = true;
     }
 
+    enable = ui.disableWhileTypingCheckBox->checkState() == Qt::Checked;
+    if (enable != (device.disableWhileTypingEnabled() > 0))
+    {
+        device.setDisableWhileTypingEnabled(enable);
+        acceptSetting = true;
+    }
+
     enable = ui.tapToDragEnabledCheckBox->checkState() == Qt::Checked;
     if (enable != (device.tapToDragEnabled() > 0))
     {
@@ -189,6 +228,13 @@ void TouchpadConfig::applyConfig()
         acceptSetting = true;
     }
 
+    enable = ui.dragLockEnabledCheckBox->checkState() == Qt::Checked;
+    if (enable != (device.dragLockEnabled() > 0))
+    {
+        device.setDragLockEnabled(enable);
+        acceptSetting = true;
+    }
+
     float accelSpeed = static_cast<float>(ui.accelSpeedDoubleSpinBox->value());
     if (accelSpeed != device.accelSpeed())
     {
